@@ -22,21 +22,21 @@ isDyadic(enum function const function) {
     
     switch (function) {
     case FN_ADD:
+    case FN_MULTIPLY:
+    case FN_MINIMUM:
+    case FN_MAXIMUM:
     case FN_MEAN:
     case FN_AND:
+    case FN_NAND:
     case FN_OR:
+    case FN_NOR:
     case FN_XOR:
         retval = FALSE;
         break;
     case FN_SUBTRACT:
     case FN_DIFFERENCE:
-    case FN_MINIMUM:
-    case FN_MAXIMUM:
     case FN_COMPARE:
-    case FN_MULTIPLY:
     case FN_DIVIDE:
-    case FN_NAND:
-    case FN_NOR:
     case FN_SHIFTLEFT:
     case FN_SHIFTRIGHT:
         retval = TRUE;
@@ -47,7 +47,7 @@ isDyadic(enum function const function) {
 
 
 
-struct cmdlineInfo {
+struct CmdlineInfo {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
@@ -60,7 +60,7 @@ struct cmdlineInfo {
 
 static void
 parseCommandLine(int argc, const char ** const argv,
-                 struct cmdlineInfo * const cmdlineP) {
+                 struct CmdlineInfo * const cmdlineP) {
 /*----------------------------------------------------------------------------
    Note that the file spec array we return is stored in the storage that
    was passed to us as the argv array.
@@ -213,6 +213,30 @@ functionCategory(enum function const function) {
 
 
 
+static int
+outFmtForCompare(int const format1,
+                 int const format2) {
+/*----------------------------------------------------------------------------
+   The format for the output image, given that the function is Compare and
+   'format1' and 'format2' are the input image formats.
+
+   Note that Compare is special because its maxval is always 2, and that
+   won't work for PBM.
+-----------------------------------------------------------------------------*/
+    int const tentativeFormat = MAX(format1, format2);
+
+    int retval;
+
+    switch (tentativeFormat) {
+    case PBM_FORMAT:  retval = PGM_FORMAT;      break;
+    case RPBM_FORMAT: retval = RPGM_FORMAT;     break;
+    default:          retval = tentativeFormat; break;
+    }
+    return retval;
+}
+
+
+
 static void
 computeOutputType(struct pam *  const outpamP,
                   struct pam    const inpam1,
@@ -222,13 +246,17 @@ computeOutputType(struct pam *  const outpamP,
     outpamP->size        = sizeof(struct pam);
     outpamP->len         = PAM_STRUCT_SIZE(tuple_type);
     outpamP->file        = stdout;
-    outpamP->format      = MAX(inpam1.format, inpam2.format);
     outpamP->plainformat = FALSE;
     outpamP->height      = inpam1.height;
     outpamP->width       = inpam1.width;
     outpamP->depth       = MAX(inpam1.depth, inpam2.depth);
 
-    switch (functionCategory(function)) {    
+    if (function == FN_COMPARE)
+        outpamP->format = outFmtForCompare(inpam1.format, inpam2.format);
+    else
+        outpamP->format = MAX(inpam1.format, inpam2.format);
+
+    switch (functionCategory(function)) {
     case CATEGORY_FRACTIONAL_ARITH:
         if (function == FN_COMPARE)
             outpamP->maxval = 2;
@@ -265,7 +293,7 @@ computeOutputType(struct pam *  const outpamP,
 
 
 
-static sample
+static samplen
 samplenSum(samplen      const operands[],
            unsigned int const operandCt) {
 
@@ -282,7 +310,7 @@ samplenSum(samplen      const operands[],
 
 
 
-static sample
+static samplen
 samplenMin(samplen      const operands[],
            unsigned int const operandCt) {
 
@@ -298,7 +326,7 @@ samplenMin(samplen      const operands[],
 
 
 
-static sample
+static samplen
 samplenMax(samplen      const operands[],
            unsigned int const operandCt) {
 
@@ -314,7 +342,7 @@ samplenMax(samplen      const operands[],
 
 
 
-static sample
+static samplen
 samplenMean(samplen      const operands[],
             unsigned int const operandCt) {
 
@@ -329,7 +357,7 @@ samplenMean(samplen      const operands[],
 
 
 
-static sample
+static samplen
 samplenProduct(samplen      const operands[],
                unsigned int const operandCt) {
 
@@ -541,7 +569,7 @@ sampleProduct(sample       const operands[],
     double product;
 
     for (i = 0, product = 1.0; i < operandCt; ++i) {
-        product *= ((double)operands[0]/maxval);
+        product *= ((double)operands[i]/maxval);
     }
     return (sample)(product * maxval + 0.5);
 }
@@ -796,7 +824,7 @@ doUnNormalizedArith(struct pam *  const inpam1P,
 int
 main(int argc, const char *argv[]) {
 
-    struct cmdlineInfo cmdline;
+    struct CmdlineInfo cmdline;
     struct pam inpam1;
     struct pam inpam2;
     struct pam outpam;
@@ -835,7 +863,7 @@ main(int argc, const char *argv[]) {
 
     switch (functionCategory(cmdline.function)) {    
     case CATEGORY_FRACTIONAL_ARITH:
-        if (inpam1.maxval == inpam2.maxval)
+        if (inpam1.maxval == inpam2.maxval && inpam2.maxval == outpam.maxval)
             doUnNormalizedArith(&inpam1, &inpam2, &outpam, cmdline.function);
         else
             doNormalizedArith(&inpam1, &inpam2, &outpam, cmdline.function);
